#WiNoT®

WiNoT® is a range of products from Qantom Software Private Limited that makes it easy for IOT implementors to create wireless enabled IOT solutions without the need for complex embedded or socket programming knowledge. 
The core principles of WiNoT® products are
It must be easy for people who are not electronic engineers or computer science specialists to be able to create IOT solutions
Must follow the 3-Easy-C principle - Easy to a)Create, b)Configure and c)Customize
Wireless intelligence must be built into the product. Any developer who wants to create customized sensors and output devices must be able to do so in easy steps